@@ -4,7 +4,7 @@ use strict;
 use LWP::UserAgent ();
 use Carp ();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 our $DOMAIN = 'antigate.com'; # service domain often changes because of the abuse
 our $WAIT   = 220;            # default time that recognize() or upload() can work
@@ -88,6 +88,7 @@ sub try_upload
     Carp::croak "Captcha file or content should be specified and exists"
         if (!defined($opts{file}) && !defined($opts{content})) || (defined($opts{file}) && ! -e $opts{file});
     
+    my $file;
     my $response = $self->{ua}->post
         (
             "http://$self->{domain}/in.php",
@@ -100,12 +101,12 @@ sub try_upload
                 [
                     defined($opts{file}) ?
                         (
-                            delete $opts{file},
+                            $file = delete $opts{file},
                             defined($opts{name}) ?
                                 delete $opts{name}
                                 :
-                                $opts{file} !~ /\..{1,5}$/ ? # filename without extension
-                                    _name_by_file_signature($opts{file})
+                                $file !~ /\..{1,5}$/ ? # filename without extension
+                                    _name_by_file_signature($file)
                                     :
                                     undef
                         )
@@ -511,6 +512,8 @@ This method tries to upload captcha image to the service. Here you can use the f
    min_len         0            minimum length of the captcha text (0..20)
    max_len         0            maximum length of the captcha text (0..20), 0 - no limits
    is_russian      0            1 - russian text only, 2 - russian or english, 0 - does not matter
+   soft_id         undef        id of your application to earn money
+   header_acao     0            1 if server should return "Access-Control-Allow-Origin: *" header
    
 You must specify either `file' option or `content'. Other options are facultative. If you want to upload captcha from variable
 (`content' option) instead from file, you must specify the name of the file with `name' option. Antigate webservice determines
@@ -519,6 +522,9 @@ no extension and `name' was not specified or if `content' option used and `name'
 specify proper name by file signature. If file has unknown signature $WebService::Antigate::FNAME will be used as file name.
 On success captcha id is returned. On failure returns undef and sets errno and errstr.
 
+This list of settings supported by the service may be outdated. But you can specify any other options supported by the service
+here without any changes of the module.
+
 =item $recognizer->upload(%options)
 
 This method attempts to upload a captcha image to the service until exceeds allotted time limit or attempts or a captcha
